summaryrefslogtreecommitdiff
path: root/include/comphelper/numbers.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-10-19 12:51:29 +0200
committerNoel Grandin <noelgrandin@gmail.com>2015-10-20 07:05:25 +0000
commit1b62841b1859ae3443e2bf1ebe99ec3d6afb6cc2 (patch)
treee3b7af8a34c55d7aad95752ad5d642a271523d08 /include/comphelper/numbers.hxx
parentb1659c95b0620cfd1291f889eae767757f696ae1 (diff)
com::sun::star->css in include/comphelper
Change-Id: Ice569b724732da1fd67a18a4ccf2f92f530cd689 Reviewed-on: https://gerrit.libreoffice.org/19459 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Noel Grandin <noelgrandin@gmail.com>
Diffstat (limited to 'include/comphelper/numbers.hxx')
-rw-r--r--include/comphelper/numbers.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/comphelper/numbers.hxx b/include/comphelper/numbers.hxx
index 7cb8840f18d3..7ed2e2b4190d 100644
--- a/include/comphelper/numbers.hxx
+++ b/include/comphelper/numbers.hxx
@@ -29,10 +29,10 @@
namespace comphelper
{
/// returns the ::com::sun::star::util::NumberFormat of the given key under the given formats
COMPHELPER_DLLPUBLIC sal_Int16 getNumberFormatType(const css::uno::Reference<css::util::XNumberFormats>& xFormats, sal_Int32 nKey);
/// returns the ::com::sun::star::util::NumberFormat of the given key under the given formatter
COMPHELPER_DLLPUBLIC sal_Int16 getNumberFormatType(const css::uno::Reference<css::util::XNumberFormatter>& xFormatter, sal_Int32 nKey);
/// returns the decimals of the given numeric number formatunder the given formats
@@ -47,8 +47,8 @@ namespace comphelper
/** retrieves a the value of a given property for a given format key, relating to a given formatter
*/
- COMPHELPER_DLLPUBLIC ::com::sun::star::uno::Any getNumberFormatProperty(
- const ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatter >& _rxFormatter,
+ COMPHELPER_DLLPUBLIC css::uno::Any getNumberFormatProperty(
+ const css::uno::Reference< css::util::XNumberFormatter >& _rxFormatter,
sal_Int32 _nKey,
const OUString& _rPropertyName
);
@@ -29,10 +29,10 @@
namespace comphelper
{
- /// returns the ::com::sun::star::util::NumberFormat of the given key under the given formats
+ /// returns the css::util::NumberFormat of the given key under the given formats
COMPHELPER_DLLPUBLIC sal_Int16 getNumberFormatType(const css::uno::Reference<css::util::XNumberFormats>& xFormats, sal_Int32 nKey);
@@ -29,10 +29,10 @@
COMPHELPER_DLLPUBLIC sal_Int16 getNumberFormatType(const css::uno::Reference<css::util::XNumberFormats>& xFormats, sal_Int32 nKey);
- /// returns the ::com::sun::star::util::NumberFormat of the given key under the given formatter
+ /// returns the css::util::NumberFormat of the given key under the given formatter
COMPHELPER_DLLPUBLIC sal_Int16 getNumberFormatType(const css::uno::Reference<css::util::XNumberFormatter>& xFormatter, sal_Int32 nKey);
/// returns the decimals of the given numeric number formatunder the given formats